@@ -10,73 +10,6 @@
 ###################################################################################################
 
 
-# test.RTest.test_returnValue_data.frame_cellbycell ###############################################
-
-#' Test Function For Testing Function 'RTest::test_returnValue_data.frame_cellbycell'
-#' 
-#' @name     test.RTest.test_returnValue_data.frame_cellbycell
-#' @aliases  test.RTest.test_returnValue_data.frame_cellbycell,RTestCase-method
-#' 
-#' @param    object          (\code{object}) The \code{\link{RTestCase-class}} object
-#' 
-#' @return   (\code{list})
-#' 
-#' @seealso  \code{\link{RTestCase-class}}
-#' 
-#' @author   Matthias Pfeifer \email{matthias.pfeifer@@roche.com}
-setTestMethod(
-  "test.RTest.test_returnValue_data.frame_cellbycell", 
-  signature  = "RTestCase",
-  definition = function(object, inputData, execCache, xmlDef, ...) {
-
-    # Get function parameters ---------------------------------------------------------------------
-
-    # ... not required ...
-        
-    
-    # Get reference for test case -----------------------------------------------------------------
-    
-    reference <- xmlReadData_data.frame(xmlDef[["reference"]])
-      
-
-    # Calculate Result ----------------------------------------------------------------------------
-    
-    result <- inputData
-    
-
-    # Execute test --------------------------------------------------------------------------------
-    
-    test_returnValue_data.frame_cellbycell(result, reference, xmlDef[["testspec"]])    
-    
-    
-    # Print some summary --------------------------------------------------------------------------
-    
-    RTest.cat("\n\n")
-    RTest.cat("**************************\n")
-    RTest.cat("    test.Pkg_1.funct_01   \n")
-    
-    RTest.cat("inputData (passed by function call)\n")
-    RTest.print(inputData)
-    
-    RTest.cat("execCache (passed by function call)\n")
-    RTest.print(execCache)
-    
-    RTest.cat("reference\n")
-    RTest.print(reference)
-    
-    RTest.cat("result\n")
-    RTest.print(result)
-    
-    RTest.cat("\n**************************\n")
-    RTest.cat("\n\n")
-    
-
-    # Return result (will be cached) --------------------------------------------------------------
-    
-    return(result)
-  }
-)
-
 #' A simple function to Test the RTest package
 #' 
 #' @param dat (\code{data.frame}) Any simple number dataframe with minimum one column
@@ -127,7 +60,6 @@ setTestMethod(
 					what        = "test_fun",
 					args        = list(dat=inputData[[1]], mult=mult),
 					xmlTestSpec = xmlDef[["testspec"]][["execution"]])
-			
 			# Read reference
 			reference <- xmlReadData_data.frame(xmlDef[["reference"]])
 			
@@ -283,8 +215,12 @@ setTestMethod(
 		signature = "RTestCase",
 		definition = function(object, inputData, execCache, xmlDef, package=NULL, ...) {
 			
+		arguments_call <- list()
+		
+		if(!is.null(xmlDef[["params"]])){
 	### ------ Derive call arguments ------ ######			
 			arguments_call <- xmlDef[["params"]] %>% arguments_creator(input_data = inputData)	
+		}
 
 	### ------ Create execution xmlTestSpec ------ ######			
 			# Double check that testSpec is existing
@@ -320,20 +256,23 @@ setTestMethod(
 			reference <- xmlReadData_to_list(
 					xmlNode("reference_data",xmlDef[["reference"]]))[["reference"]]
 			
+			if(!is.null(reference)){
+				
 	### ------ Result vs Reference ----- #####	
-			# - Special case - Image
-			if(!is.null(xmlAttrs(xmlDef[["reference"]])["image"]) && 
-					!is.na(xmlAttrs(xmlDef[["reference"]])["image"])){
-				if(!is.null(xmlAttrs(xmlDef[["reference"]])["exec_value"]) &&
-						!is.na(xmlAttrs(xmlDef[["reference"]])["exec_value"])){
-					reference <- eval(parse(text=reference))
+				# - Special case - Image
+				if(!is.null(xmlAttrs(xmlDef[["reference"]])["image"]) && 
+						!is.na(xmlAttrs(xmlDef[["reference"]])["image"])){
+					if(!is.null(xmlAttrs(xmlDef[["reference"]])["exec_value"]) &&
+							!is.na(xmlAttrs(xmlDef[["reference"]])["exec_value"])){
+						reference <- eval(parse(text=reference))
+					}
+					test_returnValue_image(result, reference,  xmlDef[["testspec"]][["return-value"]],
+							)
+				# - All other cases -
+				}else{
+					test_returnValue_any(result, reference,  xmlDef[["testspec"]][["return-value"]]
+							)
 				}
-				test_returnValue_image(result, reference,  xmlDef[["testspec"]][["return-value"]],
-						)
-			# - All other cases -
-			}else{
-				test_returnValue_any(result, reference,  xmlDef[["testspec"]][["return-value"]]
-						)
 			}
 	
 			return(result)
